.. _gaze:

Gaze Module
===========

.. automodule:: eyetrace.gaze
   :members:
   :undoc-members:
   :show-inheritance:

.. rubric:: Overview

The gaze module provides tools for analyzing eye movements, including saccades, fixations, gaze entropy, 3D gaze vectors, vergence, and pupil eccentricity. These metrics are essential for studying visual attention, oculomotor control, and neurological conditions.

.. rubric:: Submodules

.. toctree::
   :maxdepth: 1
   :caption: Gaze Submodules

   gaze.saccades
   gaze.fixation
   gaze.entropy
   gaze.vector_3d
   gaze.vergence
   gaze.eccentricity